import React, { Component } from 'react';
import { TextareaItem, DatePicker, Button, Toast } from 'antd-mobile';
import { applyPublicCar, fetchCarCategory } from '../../api/index';
import styles from './style.css';
import { formatDate } from '../../utils/index';
import arrIcon from '../../components/Input/Select/images/select_icon@2x.png';

const CustomChildren = ({ extra, onClick, children }) => (
  <div onClick={onClick} className={styles.selectWrap}>
    <div className={extra === '请选择' ? '' : styles.selectValue}>
      {extra === '请选择' ? '年-月-日 时-分' : extra}
    </div>
  </div>
);

class PublicCarApply extends Component {
  constructor(props) {
    super(props);
    this.state = {
      department: '',
      createDate: formatDate(new Date(), 'yyyy-MM-dd'),
      name: '',
      categoryId: '',
      userCount: '',
      beginDate: '',
      endDate: '',
      lineDescription: '',
      showAllCategory: true,
      categoryList: [],
    };
  }
  componentDidMount() {
    fetchCarCategory().then(res => {
      this.setState({
        categoryList: res.data,
      });
    });
  }
  selectCategory = id => {
    this.setState({
      categoryId: id,
    });
  };
  validateForm = () => {
    if (!this.state.categoryId) {
      Toast.fail('请选择用车类型');
      return false;
    }
    if (!this.state.userCount) {
      Toast.fail('请填写用车人数');
      return false;
    }
    if (!this.state.beginDate) {
      Toast.fail('请选择用车开始时间');
      return false;
    }
    if (!this.state.endDate) {
      Toast.fail('请选择用车结束时间');
      return false;
    }
    return true;
  };
  onSubmit = () => {
    if (!this.validateForm()) {
      return;
    }
    let categoryName = JSON.stringify(
      this.state.categoryList.map(i => ({
        id: i.id,
        name: i.name,
        checked: i.id === this.state.categoryId,
      }))
    );
    const entity = {
      department: this.state.department,
      name: this.state.name,
      categoryName: categoryName,
      beginDate: this.state.beginDate,
      endDate: this.state.endDate,
      lineDescription: this.state.lineDescription,
      userCount: this.state.userCount,
    };
    applyPublicCar(entity)
      .then(res => {
        console.log('res: ' + res);
      })
      .catch(err => {
        console.log('err: ' + err);
      });
    // sendMsg({
    //   cellphone: '18108096099',
    // })
    //   .then(res => {
    //     console.log(res);
    //     Toast.success('发送成功！');
    //   })
    //   .catch(err => {
    //     console.log(err);
    //   });
  };
  render() {
    const {
      name,
      department,
      createDate,
      categoryList,
      categoryId,
      lineDescription,
    } = this.state;
    return (
      <div className={styles.bg}>
        <div className={styles.content}>
          <div className={styles.listItem}>
            <div className={styles.itemLabel}>用车部门</div>
            <div className={styles.itemValue}>{department}</div>
          </div>
          <div className={styles.listItem}>
            <div className={styles.itemLabel}>申请时间</div>
            <div className={styles.itemValue}>{createDate}</div>
          </div>
          <div className={styles.listItem}>
            <div className={styles.itemLabel}>申请人</div>
            <div className={styles.itemValue}>{name}</div>
          </div>
          <div className={styles.listItemAutoHeight}>
            <div className={styles.itemLabel}>用车类型</div>
            <div className={styles.itemValue}>
              <div className={styles.selectInput}>
                请选择
                <span className={styles.arrow}>
                  <img src={arrIcon} alt="" />
                </span>
              </div>
              {categoryList.map(i => (
                <div
                  key={i.id}
                  className={styles.optionItem}
                  onClick={() => this.selectCategory(i.id)}
                >
                  <div className={styles.radioLabel}>
                    {i.id === categoryId ? (
                      <div className={styles.inner} />
                    ) : null}
                  </div>
                  <div className={styles.radioValue}>{i.name}</div>
                </div>
              ))}
            </div>
          </div>
          <div className={styles.listItem}>
            <div className={styles.itemLabel}>用车人数</div>
            <div className={styles.itemValue}>
              <input
                className={styles.itemInput}
                type="text"
                value={this.state.userCount}
                onChange={e =>
                  this.setState({
                    userCount: e.target.value,
                  })
                }
              />
            </div>
          </div>
          <div className={styles.listItem}>
            <div className={styles.itemLabel}>用车开始时间</div>
            <div className={styles.itemSelect}>
              <DatePicker
                value={this.state.beginDate}
                onChange={date => this.setState({ beginDate: date })}
              >
                <CustomChildren className={styles.DateInnerWrap} />
              </DatePicker>
            </div>
          </div>
          <div className={styles.listItem}>
            <div className={styles.itemLabel}>用车结束时间</div>
            <div className={styles.itemSelect}>
              <DatePicker
                className={styles.DateWrap}
                value={this.state.endDate}
                onChange={date => this.setState({ endDate: date })}
              >
                <CustomChildren className={styles.DateInnerWrap} />
              </DatePicker>
            </div>
          </div>
          <div className={styles.listItemAutoHeight}>
            <div className={styles.itemLabel}>用车详细线路</div>
            <div className={styles.itemValue}>
              <TextareaItem
                className={styles.textarea}
                placeholder="例：温江校区-富顺县-川大望江校区"
                rows={4}
                count={50}
                value={lineDescription}
                onChange={val => this.setState({ lineDescription: val })}
              />
            </div>
          </div>
        </div>
        <Button className={styles.submitBtn} onClick={this.onSubmit}>
          提交
        </Button>
      </div>
    );
  }
}

export default PublicCarApply;
