import React, { Component } from 'react';
import { PullToRefresh, Modal } from 'antd-mobile';
import styles from './style.css';
import RepairItem from './components/RepairItem';
import { fetchRepairList } from '../../api/index';
import Perview from '../../components/Perview/Perview';

class RepairList extends Component {
  constructor(props) {
    super(props);
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      pagination: {
        pageNum: 1,
        pageSize: 50,
      },
      list: [],
      perviewVisibility: false,
      selectedImgList: [],
      perviewIndex: 0,
    };
  }
  componentDidMount() {
    let wrap = document.querySelector('.RepairContent');
    const hei = wrap.clientHeight;
    setTimeout(
      () =>
        this.setState({
          height: hei,
        }),
      0
    );
    const { pagination } = this.state;
    fetchRepairList({
      ...pagination,
    }).then(res => {
      console.log(res);
      this.setState({
        list: res.data,
      });
    });
  }
  refreshHandle = () => {
    this.setState({ refreshing: true });
    setTimeout(() => {
      this.setState({ refreshing: false });
    }, 1000);
  };
  showViewHandle = (list, index) => {
    this.setState({
      perviewVisibility: true,
      perviewIndex: index,
      selectedImgList: list,
    });
  };
  resetDialog = () => {
    this.setState({
      perviewVisibility: false,
    });
  };
  render() {
    const { perviewVisibility, selectedImgList, perviewIndex } = this.state;
    return (
      <div className={styles.repairList}>
        <PullToRefresh
          damping={60}
          ref={el => (this.ptr = el)}
          style={{
            height: this.state.height,
            overflow: 'auto',
          }}
          indicator={{ deactivate: '上拉可以刷新' }}
          direction={'up'}
          refreshing={this.state.refreshing}
          onRefresh={this.refreshHandle}
        >
          <div className={styles.listInfo}>显示最近半年的报修记录</div>
          {this.state.list.length ? (
            this.state.list.map(i => (
              <RepairItem key={i.id} data={i} showView={this.showViewHandle} />
            ))
          ) : (
            <div className={styles.noData}>暂无数据</div>
          )}
        </PullToRefresh>
        <Modal
          className={styles.perViewDialog}
          visible={perviewVisibility}
          transparent
          maskClosable={true}
          onClose={this.resetDialog}
          title=""
        >
          <Perview data={selectedImgList} index={perviewIndex} />
        </Modal>
      </div>
    );
  }
}

export default RepairList;
